SystemOrganization addCategory: #ConfigurationOfFilesystem!

Object subclass: #ConfigurationOfFilesystem
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfFilesystem'!

!ConfigurationOfFilesystem commentStamp: 'StephaneDucasse 7/2/2011 16:41' prior: 0!
(ConfigurationOfFilesystem project version:  '2.0.1') load

(MetacelloToolBox validateConfiguration: ConfigurationOfFilesystem)
	inspect 
	
 MetacelloToolBox descriptionForValidationReasonCode: #noVersionSpecified!

!ConfigurationOfFilesystem class methodsFor: 'development support' stamp: 'CamilloBruni 1/19/2012 16:03'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfFilesystem class methodsFor: 'private' stamp: 'tbn 2/5/2010 13:13'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfFilesystem class methodsFor: 'development support' stamp: 'CamilloBruni 1/19/2012 16:02'!
createNewBaselineVersion
	"Create a new baseline version based upon the #stable version's baseline.
	 A new baseline should be created if new packages have been added or package dependencies have changed."

	"self createNewDevelopmentVersion"

	<apiDocumentation>
	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewBaselineVersionIn: self description: ''
! !

!ConfigurationOfFilesystem class methodsFor: 'development support' stamp: 'CamilloBruni 1/19/2012 16:02'!
createNewDevelopmentVersion
	"Create a new development version using the #stable version as model."

	"self createNewDevelopmentVersion"

	<apiDocumentation>
	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewDevelopmentVersionIn: self description: ''! !

!ConfigurationOfFilesystem class methodsFor: 'private' stamp: 'tbn 2/5/2010 13:13'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfFilesystem class methodsFor: 'metacello tool support' stamp: 'tbn 2/5/2010 13:13'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfFilesystem class methodsFor: 'metacello tool support' stamp: 'tbn 2/5/2010 13:13'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfFilesystem class methodsFor: 'loading' stamp: 'tbn 2/5/2010 13:13'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfFilesystem class methodsFor: 'loading' stamp: 'DamienCassou 4/17/2011 10:50'!
loadBleedingEdge
	"self loadBleedingEdge"

	^self project bleedingEdge load! !

!ConfigurationOfFilesystem class methodsFor: 'metacello tool support' stamp: 'tbn 2/5/2010 13:13'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfFilesystem class methodsFor: 'accessing' stamp: 'tbn 2/5/2010 13:13'!
project

	^self new project! !

!ConfigurationOfFilesystem class methodsFor: 'development support' stamp: 'CamilloBruni 1/19/2012 16:02'!
saveConfiguration: commitMessage
	"Save mcz file that contains the configuration to it's repository."

	"self saveConfiguration: '- fixed bug'"

	<apiDocumentation>
	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveConfigurationPackageFor: self name asString description: commitMessage! !

!ConfigurationOfFilesystem class methodsFor: 'development support' stamp: 'CamilloBruni 1/19/2012 16:02'!
saveModifiedPackagesAndConfiguration: commitMessage
	"Save modified mcz files, update the #development version and then save the configuration."

	"self saveModifiedPackagesAndConfiguration: '- fixed bug'"

	<apiDocumentation>
	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesAndConfigurationIn: self description: commitMessage! !

!ConfigurationOfFilesystem class methodsFor: 'development support' stamp: 'CamilloBruni 1/19/2012 16:03'!
updateToLatestPackageVersions: descriptionString
	"Update the #development version to match currently loaded mcz files."

	"self updateToLatestPackageVersions: '- fixed a bug'"

	<apiDocumentation>
	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfFilesystem class methodsFor: 'development support' stamp: 'CamilloBruni 1/19/2012 16:03'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfFilesystem methodsFor: 'baselines' stamp: 'MaxLeske 8/25/2011 19:53'!
baseline100: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.source.wiresong.ca/mc'.	
		spec 
			package: 'Filesystem'.
		spec
			group: 'default' with: #('Filesystem')].! !

!ConfigurationOfFilesystem methodsFor: 'baselines' stamp: 'StephaneDucasse 2/4/2011 13:27'!
baseline200: spec 
	<version: '2.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/fs'.	
		spec package: 'Filesystem'.
		spec
			group: 'default' with: #('Filesystem')].! !

!ConfigurationOfFilesystem methodsFor: 'baselines' stamp: 'TudorGirba 4/7/2011 14:34'!
baseline201: spec 
	<version: '2.0.1-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/fs'.	
		spec 
			package: 'FS-Core';
			package: 'FS-Disk' with: [spec requires: 'FS-Core'];
			package: 'FS-FileStream';
			package: 'FS-Memory' with: [spec requires: #('FS-Core' 'FS-FileStream')];
			package: 'FS-Zip' with: [spec requires: #('FS-Memory')];
			package: 'FS-AnsiStreams';
			package: 'FS-Tests-Core';
			package: 'FS-Tests-AnsiStreams';
			package: 'FS-Tests-Disk' with: [spec requires: 'FS-Tests-Core'];
			package: 'FS-Tests-Memory' with: [spec requires: 'FS-Tests-Core'].
		spec
			group: 'Tests' with: #('FS-Tests-Core' 'FS-Tests-AnsiStreams' 'FS-Tests-Disk' 'FS-Tests-Memory')].! !

!ConfigurationOfFilesystem methodsFor: 'baselines' stamp: 'MaxLeske 8/14/2011 23:18'!
baseline202: spec 
	<version: '2.0.2-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/fs'.	
		spec 
			package: 'FS-Core';
			package: 'FS-Disk' with: [spec requires: 'FS-Core'];
			package: 'FS-FileStream';
			package: 'FS-Memory' with: [spec requires: #('FS-Core' 'FS-FileStream')];
			package: 'FS-Zip' with: [spec requires: #('FS-Memory')];
			package: 'FS-AnsiStreams';
			package: 'FS-Tests-Core';
			package: 'FS-Tests-AnsiStreams';
			package: 'FS-Tests-Disk' with: [spec requires: 'FS-Tests-Core'];
			package: 'FS-Tests-Memory' with: [spec requires: 'FS-Tests-Core'];
			package: 'FS-Help'.
		spec
			group: 'Tests' with: #('FS-Tests-Core' 'FS-Tests-AnsiStreams' 'FS-Tests-Disk' 'FS-Tests-Memory')].! !

!ConfigurationOfFilesystem methodsFor: 'baselines' stamp: 'CamilloBruni 1/19/2012 16:04'!
baseline203: spec
	<version: '2.0.3-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.squeaksource.com/fs'.
		spec 
			package: 'FS-Core';
			package: 'FS-Disk' with: [
				spec requires: #('FS-Core' ). ];
			package: 'FS-FileStream';
			package: 'FS-Memory' with: [
				spec requires: #('FS-Core' 'FS-FileStream' ). ];
			package: 'FS-Zip' with: [
				spec requires: #('FS-Memory' ). ];
			package: 'FS-AnsiStreams';
			package: 'FS-Tests-Core';
			package: 'FS-Tests-AnsiStreams';
			package: 'FS-Tests-Disk' with: [
				spec requires: #('FS-Tests-Core' ). ];
			package: 'FS-Tests-Memory' with: [
				spec requires: #('FS-Tests-Core' ). ];
			package: 'FS-Help'.
		spec group: 'Tests' with: #('FS-Tests-Core' 'FS-Tests-AnsiStreams' 'FS-Tests-Disk' 'FS-Tests-Memory' ). ].
! !

!ConfigurationOfFilesystem methodsFor: 'baselines' stamp: 'TudorGirba 4/7/2011 14:02'!
default: spec 
	<version: 'default'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/fs'.	
		spec 
			package: 'FS-Core';
			package: 'FS-Disk' with: [spec requires: 'FS-Core'];
			package: 'FS-FileStream';
			package: 'FS-Memory' with: [spec requires: #('FS-Core' 'FS-FileStream')];
			package: 'FS-Zip' with: [spec requires: #('FS-Memory')];
			package: 'FS-AnsiStreams';
			package: 'FS-Tests-Core';
			package: 'FS-Tests-AnsiStreams';
			package: 'FS-Tests-Disk' with: [spec requires: 'FS-Tests-Core'];
			package: 'FS-Tests-Memory' with: [spec requires: 'FS-Tests-Core'].
		spec
			group: 'default' with: #('FS-Core')].! !

!ConfigurationOfFilesystem methodsFor: 'symbolic versions' stamp: 'CamilloBruni 1/19/2012 16:04'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '2.0.4'.
! !

!ConfigurationOfFilesystem methodsFor: 'accessing' stamp: 'tbn 2/5/2010 13:13'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfFilesystem methodsFor: 'symbolic versions' stamp: 'DamienPollet 10/5/2011 17:07'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '2.0.3'.
! !

!ConfigurationOfFilesystem methodsFor: 'versions' stamp: 'MaxLeske 8/25/2011 19:40'!
version101: spec 
	<version: '1.0.1' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'Filesystem' with: 'Filesystem-cwp.63'].! !

!ConfigurationOfFilesystem methodsFor: 'versions' stamp: 'MaxLeske 8/25/2011 19:41'!
version200: spec 
	<version: '2.0' imports: #('2.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec package: 'Filesystem' with: 'Filesystem-cwp.12' ].! !

!ConfigurationOfFilesystem methodsFor: 'versions' stamp: 'StephaneDucasse 7/5/2011 16:45'!
version201: spec 
	<version: '2.0.1' imports: #('2.0.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec package: 'FS-Core' with: 'FS-Core-StephaneDucasse.4'.
		spec package: 'FS-Disk' with: 'FS-Disk-cwp.1'.
		spec package: 'FS-FileStream' with:  'FS-FileStream-cwp.1'.
		spec package: 'FS-Memory' with:  'FS-Memory-cwp.1'.
		spec package: 'FS-Zip' with: 'FS-Zip-cwp.1'.
		spec package: 'FS-AnsiStreams' with: 'FS-AnsiStreams-cwp.1'.
		spec package: 'FS-Tests-Core' with: 'FS-Tests-Core-StephaneDucasse.3'.
		spec package: 'FS-Tests-AnsiStreams' with: 'FS-Tests-AnsiStreams-cwp.1'.
		spec package: 'FS-Tests-Disk' with: 'FS-Tests-Disk-cwp.1'.
		spec package: 'FS-Tests-Memory' with: 'FS-Tests-Memory-cwp.1'.
	]

! !

!ConfigurationOfFilesystem methodsFor: 'versions' stamp: 'MaxLeske 8/25/2011 18:44'!
version202: spec
	<version: '2.0.2' imports: #('2.0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: 'MaxLeske'.
		spec timestamp: '8/14/2011 23:17'.
		spec 
			package: 'FS-Core' with: 'FS-Core-StephaneDucasse.4';
			package: 'FS-Disk' with: 'FS-Disk-cwp.1';
			package: 'FS-FileStream' with: 'FS-FileStream-cwp.1';
			package: 'FS-Memory' with: 'FS-Memory-cwp.1';
			package: 'FS-Zip' with: 'FS-Zip-cwp.1';
			package: 'FS-AnsiStreams' with: 'FS-AnsiStreams-cwp.1';
			package: 'FS-Tests-Core' with: 'FS-Tests-Core-StephaneDucasse.3';
			package: 'FS-Tests-AnsiStreams' with: 'FS-Tests-AnsiStreams-cwp.1';
			package: 'FS-Tests-Disk' with: 'FS-Tests-Disk-cwp.1';
			package: 'FS-Tests-Memory' with: 'FS-Tests-Memory-cwp.1';
			package: 'FS-Help' with: 'FS-Help-MaxLeske.1' ].
! !

!ConfigurationOfFilesystem methodsFor: 'versions' stamp: 'MaxLeske 8/25/2011 21:08'!
version203: spec
	<version: '2.0.3' imports: #('2.0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: 'API improvements
* renamed mentions of #onDisk and #onMemory'.
		spec author: 'MaxLeske'.
		spec timestamp: '8/25/2011 19:36'.
		spec 
			package: 'FS-Core' with: 'FS-Core-CamilloBruni.15';
			package: 'FS-Disk' with: 'FS-Disk-Camillobruni.3';
			package: 'FS-FileStream' with: 'FS-FileStream-CamilloBruni.2';
			package: 'FS-Memory' with: 'FS-Memory-CamilloBruni.3';
			package: 'FS-Zip' with: 'FS-Zip-cwp.1';
			package: 'FS-AnsiStreams' with: 'FS-AnsiStreams-Camillobruni.7';
			package: 'FS-Tests-Core' with: 'FS-Tests-Core-Camillobruni.10';
			package: 'FS-Tests-AnsiStreams' with: 'FS-Tests-AnsiStreams-Camillobruni.4';
			package: 'FS-Tests-Disk' with: 'FS-Tests-Disk-Camillobruni.5';
			package: 'FS-Tests-Memory' with: 'FS-Tests-Memory-Camillobruni.4';
			package: 'FS-Help' with: 'FS-Help-MaxLeske.2'. ].
! !

!ConfigurationOfFilesystem methodsFor: 'versions' stamp: 'CamilloBruni 1/20/2012 13:48'!
version204: spec
	<version: '2.0.4' imports: #('2.0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Implemented FS improvements comments from issue 5055'.
		spec author: 'CamilloBruni'.
		spec timestamp: '1/20/2012 13:48'.
		spec 
			package: 'FS-Core' with: 'FS-Core-CamilloBruni.18';
			package: 'FS-Disk' with: 'FS-Disk-CamilloBruni.6';
			package: 'FS-FileStream' with: 'FS-FileStream-CamilloBruni.2';
			package: 'FS-Memory' with: 'FS-Memory-CamilloBruni.5';
			package: 'FS-Zip' with: 'FS-Zip-cwp.1';
			package: 'FS-AnsiStreams' with: 'FS-AnsiStreams-Camillobruni.7';
			package: 'FS-Tests-Core' with: 'FS-Tests-Core-CamilloBruni.12';
			package: 'FS-Tests-AnsiStreams' with: 'FS-Tests-AnsiStreams-Camillobruni.4';
			package: 'FS-Tests-Disk' with: 'FS-Tests-Disk-Camillobruni.5';
			package: 'FS-Tests-Memory' with: 'FS-Tests-Memory-Camillobruni.4';
			package: 'FS-Help' with: 'FS-Help-MaxLeske.2'. ].
! !
